<template>
  <ContentWrap>
    <!-- 搜索工作栏 -->
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="患者编号" prop="patId">
        <el-input
          v-model="queryParams.patId"
          placeholder="请输入患者编号"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="患者姓名" prop="patName">
        <el-input
          v-model="queryParams.patName"
          placeholder="请输入患者姓名"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="患者手机" prop="patMobile">
        <el-input
          v-model="queryParams.patMobile"
          placeholder="请输入患者手机"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
<!--
      <el-form-item label="患者电话" prop="patPhone">
        <el-input
          v-model="queryParams.patPhone"
          placeholder="请输入患者电话"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
-->
      <el-form-item label="身份证号" prop="patIdentityId">
        <el-input
          v-model="queryParams.patIdentityId"
          placeholder="请输入身份证号"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="预约编号" prop="bookId">
        <el-input
          v-model="queryParams.bookId"
          placeholder="请输入预约编号"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="检查类型" prop="bookCheckType">
        <el-select
          v-model="queryParams.bookCheckType"
          placeholder="请选择检查类型"
          clearable
          class="!w-240px"
        >
          <el-option
            v-for="dict in checkTypeStore.getCheckTypeOptions()"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
<!--
      <el-form-item label="预约来源" prop="bookSrc">
        <el-input
          v-model="queryParams.bookSrc"
          placeholder="请输入预约来源"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
-->
      <el-form-item>
        <el-button @click="handleQuery"><Icon icon="ep:search" class="mr-5px" /> 搜索</el-button>
        <el-button @click="resetQuery"><Icon icon="ep:refresh" class="mr-5px" /> 重置</el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['ecg:appointment:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" /> 新增
        </el-button>
        <el-button
          type="success"
          plain
          @click="handleExport"
          :loading="exportLoading"
          v-hasPermi="['ecg:appointment:export']"
        >
          <Icon icon="ep:download" class="mr-5px" /> 导出
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="appointmentList" :stripe="true" :show-overflow-tooltip="true">
      <el-table-column label="就诊流水号" align="center" prop="episodeId" min-width="150px"/>
      <el-table-column label="编号" align="center" prop="patId" />
      <el-table-column label="缴费" align="center" prop="paid">
        <template #default="scope">
          {{scope.row.paid == 1 ? "已付" : ""}}
        </template>
      </el-table-column>
      <el-table-column label="姓名" align="center" prop="patName" />
      <el-table-column label="性别" align="center" prop="patGender">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.SYSTEM_USER_SEX" :value="scope.row.patGender" />
        </template>
      </el-table-column>
      <el-table-column label="生日" align="center" prop="patBirthday" :formatter="dateFormatter2" width="110px"/>
      <el-table-column label="手机" align="center" prop="patMobile" />
      <el-table-column label="电话" align="center" prop="patPhone" />
      <el-table-column label="身份证号" align="center" prop="patIdentityId" />
      <el-table-column label="地址" align="center" prop="patAddr" />
      <el-table-column label="科室代码" align="center" prop="patDeptCode" />
      <el-table-column label="科室名称" align="center" prop="patDeptDesc" />
      <el-table-column label="病区代码" align="center" prop="patWardCode" />
      <el-table-column label="病区名称" align="center" prop="patWardDesc" />
      <el-table-column label="床号" align="center" prop="patBedNo" />
      <el-table-column label="预约编号" align="center" prop="bookId" />
      <el-table-column
        label="预约日期"
        align="center"
        prop="bookDate"
        :formatter="dateFormatter2"
        width="120px"
      />
      <el-table-column label="预约时间段" align="center" prop="bookTimeslot" width="100px">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.ECG_BOOK_TIMESLOT" :value="scope.row.bookTimeslot" />
        </template>
      </el-table-column>
      <el-table-column label="预约检查类型" align="center" prop="bookCheckType">
        <template #default="scope">
          {{checkTypeStore.getCheckTypeName(scope.row.bookCheckType)}}
        </template>
      </el-table-column>
      <el-table-column label="预约来源" align="center" prop="bookSrc">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.ECG_BOOK_SRC" :value="scope.row.bookSrc" />
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" min-width="120px">
        <template #default="scope">
          <el-button
            link
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['ecg:appointment:update']"
          >
            编辑
          </el-button>
          <el-button
            link
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['ecg:appointment:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <AppointmentForm ref="formRef" @event_appointment_success="getList" />
</template>

<script setup lang="ts">
import {DICT_TYPE} from '@/utils/dict'
import { dateFormatter2 } from '@/utils/formatTime'
import download from '@/utils/download'
import { AppointmentApi, AppointmentVO } from '@/api/ecg/appointment'
import AppointmentForm from './AppointmentForm.vue'
import {useCheckTypeStore} from "@/store/modules/checkType";

/** 预约 列表 */
defineOptions({ name: 'Appointment' })

const message = useMessage() // 消息弹窗
const { t } = useI18n() // 国际化

const loading = ref(true) // 列表的加载中
const appointmentList = ref<AppointmentVO[]>([]) // 列表的数据
const total = ref(0) // 列表的总页数
const queryParams = reactive({
  pageNo: 1,
  pageSize: 10,
  patId: undefined,
  patName: undefined,
  patGender: undefined,
  patBirthday: undefined,
  patMobile: undefined,
  patPhone: undefined,
  patIdentityId: undefined,
  patAddr: undefined,
  patDeptCode: undefined,
  patDeptDesc: undefined,
  patWardCode: undefined,
  patWardDesc: undefined,
  patBedNo: undefined,
  bookId: undefined,
  bookDate: undefined,
  bookTimeslot: undefined,
  bookCheckType: undefined,
  bookSrc: undefined
})
const queryFormRef = ref() // 搜索的表单
const exportLoading = ref(false) // 导出的加载中

const checkTypeStore = useCheckTypeStore();

/** 查询列表 */
const getList = async () => {
  loading.value = true
  try {
    const data = await AppointmentApi.getAppointmentPage(queryParams)
    appointmentList.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

/** 搜索按钮操作 */
const handleQuery = () => {
  queryParams.pageNo = 1
  getList()
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value.resetFields()
  handleQuery()
}

/** 添加/修改操作 */
const formRef = ref()
const openForm = (type: string, id?: number) => {
  formRef.value.open(type, id)
}

/** 删除按钮操作 */
const handleDelete = async (id: number) => {
  try {
    // 删除的二次确认
    await message.delConfirm()
    // 发起删除
    await AppointmentApi.deleteAppointment(id)
    message.success(t('common.delSuccess'))
    // 刷新列表
    await getList()
  } catch {}
}

/** 导出按钮操作 */
const handleExport = async () => {
  try {
    // 导出的二次确认
    await message.exportConfirm()
    // 发起导出
    exportLoading.value = true
    const data = await AppointmentApi.exportAppointment(queryParams)
    download.excel(data, '预约.xls')
  } catch {
  } finally {
    exportLoading.value = false
  }
}

/** 初始化 **/
onMounted(() => {
  getList()
})
</script>
